@@ -7,17 +7,9 @@
 #' @export
 #' @examples
 #' \donttest{
-#' if(curl::has_internet()) {
-#' dl_stats19(year = 2022, type = "collision")
-#' x = read_collisions(year = 2022, format = FALSE)
-#' x = readr::read_csv("https://github.com/ropensci/stats19/releases/download/v3.0.0/fatalities.csv")
-#' if(nrow(x) > 0) {
-#' x[1:3, 1:12]
-#' crashes = format_collisions(x)
-#' crashes[1:3, 1:12]
-#' summary(crashes$datetime)
-#' }
-#' }
+#'   if(curl::has_internet()) {
+#'     dl_stats19(year = 2022, type = "collision")
+#'   }
 #' }
 #' @export
 format_collisions = function(x) {
@@ -66,19 +58,24 @@ format_stats19 = function(x, type) {
   # Rename columns
   old_names = names(x)
   new_names = format_column_names(old_names)
+  # waldo::compare(old_names, new_names) They are the same for 2023 date
+  # TODO: remove format_column_names() and use stats19::stats19_schema$variable
   names(x) = new_names
 
   # create lookup table
-  lkp = stats19::stats19_variables[stats19::stats19_variables$table == type,]
+  lkp = stats19::stats19_variables[stats19::stats19_variables$table == tolower(type),]
 
-  vkeep = new_names %in% stats19::stats19_schema$variable_formatted
+  vkeep = new_names %in% stats19::stats19_schema$variable
   vars_to_change = which(vkeep)
 
+  # # for testing
   # browser()
+  # i = 1
+  # x_old = x
   for(i in vars_to_change) {
-    lkp_name = lkp$column_name[lkp$column_name == new_names[i]]
+    lkp_name = unique(lkp$variable[lkp$variable %in% new_names[i]])
     lookup = stats19::stats19_schema[
-      stats19::stats19_schema$variable_formatted == lkp_name,
+      stats19::stats19_schema$variable %in% lkp_name,
       c("code", "label")
       ]
     original_class = class(x[[i]])
@@ -88,6 +85,7 @@ format_stats19 = function(x, type) {
     x[[i]] = ifelse(is.na(matched_labels), x[[i]], matched_labels)
     x[[i]] = methods::as(x[[i]], original_class)
   }
+  # waldo::compare(x_old, x)
 
   date_in_names = "date" %in% names(x)
   if(date_in_names) {
